@@ -34,19 +34,21 @@ model_spec <- arima_boost(
 
 # * NO XREGS ----
 
-# Fit Spec
-model_fit <- model_spec %>%
-    fit(log(value) ~ date, data = training(splits))
-
-# Predictions
-predictions_tbl <- model_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits))
-
 
 # TESTS
 test_that("arima_boost: Arima, (No xregs), Test Model Fit Object", {
 
+    # Fit Spec
+    model_fit <- model_spec %>%
+        fit(log(value) ~ date, data = training(splits))
+
+    # Predictions
+    predictions_tbl <- model_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits))
+
+    # TEST
+
     testthat::expect_s3_class(model_fit$fit, "auto_arima_xgboost_fit_impl")
 
     # $fit
@@ -68,10 +70,7 @@ test_that("arima_boost: Arima, (No xregs), Test Model Fit Object", {
     testthat::expect_equal(model_fit$preproc$y_var, "value")
 
 
-
-})
-
-test_that("arima_boost: Arima, (No xregs), Test Predictions", {
+    # PREDICTIONS
 
     # Structure
     testthat::expect_identical(nrow(testing(splits)), nrow(predictions_tbl))
@@ -91,19 +90,22 @@ test_that("arima_boost: Arima, (No xregs), Test Predictions", {
 
 # * XREGS ----
 
-# Fit Spec
-model_fit <- model_spec %>%
-    fit(log(value) ~ date + as.numeric(date) + month(date, label = TRUE), data = training(splits))
-
-# Predictions
-predictions_tbl <- model_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits))
-
-
 # TESTS
 test_that("arima_boost: Arima, (XREGS), Test Model Fit Object", {
 
+    skip_on_cran()
+
+    # SETUP
+
+    # Fit Spec
+    model_fit <- model_spec %>%
+        fit(log(value) ~ date + as.numeric(date) + month(date, label = TRUE), data = training(splits))
+
+    # Predictions
+    predictions_tbl <- model_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits))
+
     testthat::expect_s3_class(model_fit$fit, "auto_arima_xgboost_fit_impl")
 
     # Structure
@@ -140,9 +142,7 @@ test_that("arima_boost: Arima, (XREGS), Test Model Fit Object", {
 
     testthat::expect_equal(model_fit$preproc$y_var, "value")
 
-})
-
-test_that("arima_boost: Arima (XREGS), Test Predictions", {
+    # PREDICTIONS
 
     # Structure
     testthat::expect_identical(nrow(testing(splits)), nrow(predictions_tbl))
@@ -163,50 +163,55 @@ test_that("arima_boost: Arima (XREGS), Test Predictions", {
 
 # ---- WORKFLOWS ----
 
-# Model Spec
-model_spec <- arima_boost(
-    seasonal_period          = 12,
-    non_seasonal_ar          = 3,
-    non_seasonal_differences = 1,
-    non_seasonal_ma          = 3,
-    seasonal_ar              = 1,
-    seasonal_differences     = 1,
-    seasonal_ma              = 1,
-    mtry  = 25,
-    trees = 250,
-    min_n = 4,
-    learn_rate = 0.1,
-    tree_depth = 7,
-    loss_reduction = 0.4,
-    sample_size = 0.9
-) %>%
-    set_engine("auto_arima_xgboost")
-
-# Recipe spec
-recipe_spec <- recipe(value ~ date, data = training(splits)) %>%
-    step_log(value, skip = FALSE) %>%
-    step_date(date, features = "month") %>%
-    step_mutate(date_num = as.numeric(date))
-
-# Workflow
-wflw <- workflow() %>%
-    add_recipe(recipe_spec) %>%
-    add_model(model_spec)
-
-wflw_fit <- wflw %>%
-    fit(training(splits))
-
-# Forecast
-predictions_tbl <- wflw_fit %>%
-    modeltime_calibrate(testing(splits)) %>%
-    modeltime_forecast(new_data = testing(splits), actual_data = training(splits)) %>%
-    mutate_at(vars(.value), exp)
-
-
 
 # TESTS
 test_that("arima_boost: Arima (workflow), Test Model Fit Object", {
 
+    skip_on_cran()
+
+    # SETUP
+    # Model Spec
+    model_spec <- arima_boost(
+        seasonal_period          = 12,
+        non_seasonal_ar          = 3,
+        non_seasonal_differences = 1,
+        non_seasonal_ma          = 3,
+        seasonal_ar              = 1,
+        seasonal_differences     = 1,
+        seasonal_ma              = 1,
+        mtry  = 25,
+        trees = 250,
+        min_n = 4,
+        learn_rate = 0.1,
+        tree_depth = 7,
+        loss_reduction = 0.4,
+        sample_size = 0.9
+    ) %>%
+        set_engine("auto_arima_xgboost")
+
+    # Recipe spec
+    recipe_spec <- recipe(value ~ date, data = training(splits)) %>%
+        step_log(value, skip = FALSE) %>%
+        step_date(date, features = "month") %>%
+        step_mutate(date_num = as.numeric(date))
+
+    # Workflow
+    wflw <- workflow() %>%
+        add_recipe(recipe_spec) %>%
+        add_model(model_spec)
+
+    wflw_fit <- wflw %>%
+        fit(training(splits))
+
+    # Forecast
+    predictions_tbl <- wflw_fit %>%
+        modeltime_calibrate(testing(splits)) %>%
+        modeltime_forecast(new_data = testing(splits), actual_data = training(splits)) %>%
+        mutate_at(vars(.value), exp)
+
+
+    # TESTS
+
     testthat::expect_s3_class(wflw_fit$fit$fit$fit, "auto_arima_xgboost_fit_impl")
 
     # Structure
@@ -244,9 +249,7 @@ test_that("arima_boost: Arima (workflow), Test Model Fit Object", {
     mld <- wflw_fit %>% workflows::pull_workflow_mold()
     testthat::expect_equal(names(mld$outcomes), "value")
 
-})
-
-test_that("arima_boost: Arima (workflow), Test Predictions", {
+    # PREDICTIONS
 
     full_data <- bind_rows(training(splits), testing(splits))
 
